---
title: <span class="badge object-type-scalar"></span> Newtons
---
# <span class="badge object-type-scalar"></span> Newtons

Force: Newtons (N)

## Definition

```python
# Force: Newtons (N)
Newtons: typing.Literal["forceN"] = "forceN"
```
